#ifndef PDCH
#define PDCH

/******************************************************************************
               PDC Constants
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif

#define PDC_MAX_WIDTH      300



#define RFLAG_RETURN_MSG_ID    0x1    // saves the msg ids to return to the user program.
#define RFLAG_FIRST_MSG_ONLY   0x2    // display only the first message

#define PDFFLAG_COMPRESS_TEXT  0x1    // the flag used by the PdcStartDoc function
#define PDFFLAG_NO_BOOKMARK    0x2    // do not include bookmark
#define PDFFLAG_EMBED_FONTS    0x4    // always embed fonts
#define PDFFLAG_NO_HLINK       0x8    // do not include active hyperlink
#define PDFFLAG_BINARY_HINT    0x10   // write additional binary hit to satish yahoo and hotmail
#define PDFFLAG_EXACT_TEXT_PLACEMENT 0x20 // place characters at exact positions
#define PDFFLAG_NO_CACHING     0x40   // write directly to disk file
#define PDFFLAG_DO_XPARENT     0x80   // support picture transparency
#define PDFFLAG_MULTI_DOC      0x100  // combining multiple TE documents to create one pdf doc
#define PDFFLAG_NO_PAGE_BM     0x200  // do not create page bitmap, page bitmap is needed to support transparency
#define PDFFLAG_NO_BOOKMARK_PANE 0x400  // do not open the bookmark pane - only applicable when bookmarks are enabled
#define PDFFLAG_RC4_128          0x800  // use RC4-128 bit encryption when password is used
#define PDFFLAG_AES_128         0x1000  // use AES-128 bit encryption when password is used
#define PDFFLAG_RETURN_MSG_ID   0x2000  // sets the RFLAG_RETURN_MSG_ID flag
#define PDFFLAG_DONT_GET_WORLDTRANSFORM  0x4000  // use identity transform all the time
#define PDFFLAG_DONT_ROUND_IMAGE_DATA    0x8000  // dont' round the image bits
#define PDFFLAG_PDFA_1B                 0x10000 // minimum compliance pdf/a-1b
#define PDFFLAG_PDFA                    0x20000 // minimum compliance pdf/a
#define PDFFLAG_SHOW_MISSING_SSZLIB_MSG 0x40000 // show a message if sszlib not found
#define PDFFLAG_HPS                     0x80000 // called from html to pdf converter
#define PDFFLAG_CLEAR_BKND             0x100000 // clear page background
#define PDFFLAG_TAGGED                 0x200000  // true to generated tagged pdf
#define PDFFLAG_NO_PAGE_SCALING        0x400000  // set the page scaling document property to None
#define PDFFLAG_DUPLEX_LONG            0x800000  // select duplex printing on the long edge
#define PDFFLAG_DUPLEX_SHORT          0x1000000  // select duplex printing on the short edge
#define PDFFLAG_PDFA3                 0x2000000 // minimum compliance pdf/a-3
#define PDFFLAG_PDF_UA                0x4000000 // PDF/UA (user accessibility) compliance
#define PDFFLAG_MINIMIZE_FILE_SIZE    0x8000000 // minimized the pdf file size
#define PDFFLAG_AES_256              0x10000000  // not yet implemented
#define PDFFLAG_PDFA_2B              0x20000000 // 20200617: minimum compliance pdf/a-2b



#define PDC_FILE              1
#define PDC_BUF               2

#define PERM_PRINT            0x4     // these values are specified by the pdf spec - permission flags
#define PERM_MOD              0x28
#define PERM_COPY             0x10
#define PERM_PRINT_HI_RES    0x800    //  allow hi-res printing even in AES_128 mode (revision 3 or greater)

#define PERM_ALL              (PERM_PRINT|PERM_MOD|PERM_COPY)

/******************************************************************************
    Message ids
*******************************************************************************/
#define RMSG_NO_ERROR            0
#define RMSG_BAD_BMP_FILE        1
#define RMSG_CREATE_NEW_FILE     2
#define RMSG_ERR_DIB_CREATE      3
#define RMSG_ERR_FILE_LENGTH     4
#define RMSG_ERR_FILE_OPEN       5
#define RMSG_ERR_FILE_READ       6
#define RMSG_ERR_FILE_SEEK       7
#define RMSG_ERR_FILE_WRITE      8
#define RMSG_ERR_FONT_CREATE     9
#define RMSG_ERR_FONT_SELECT     10
#define RMSG_ERR_INIT_BMP        11
#define RMSG_ERR_MEM_LOCK        12
#define RMSG_ERR_META_ACCESS     13
#define RMSG_ERR_META_BAD_FILE   14
#define RMSG_ERR_META_COPY       15
#define RMSG_ERR_META_CREATE     16
#define RMSG_ERR_META_READ       17
#define RMSG_ERR_META_RECREATE   18
#define RMSG_ERR_PICT_FILE_FMT   19
#define RMSG_ERR_PICT_FILE_OPEN  20
#define RMSG_ERR_PICT_FILE_READ  21
#define RMSG_LINE_TOO_LONG       22
#define RMSG_OUT_OF_MEM          23
#define RMSG_READ_ABORTED        24
#define RMSG_REPLACE_STRING      25
#define RMSG_SAVE_INCOMPL        26
#define RMSG_UNEXPECTED_EOF      27
#define RMSG_ERR_FILE_ACCESS     28
#define RMSG_ERR_ENH_META_HDR    29
#define RMSG_GET_ENH_META        30

#define RMSG_TEMP                48

/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (WIN32)
   #define PDC_HUGE
   #define _export
#else
   #define PDC_HUGE huge
#endif


/****************************************************************************
   Instructions for packing the following structure
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack(1)
#endif

#define PDFFIELD_SIGNATURE   1   // signatrue field
#define PDFFIELD_TEXT        2   // text field

struct StrPdfField {  // pdf hlink structure
    BYTE sign[2];     // signature byes 'FL'
    BOOL begin;       // true to begin the signaure bloc, false to end it
    int page;         // hyperlink page
    int x;            // x position of the signature box (in points from the top of the page)
    int y;            // y position of the signature box (in points from the left edge of the page)
    int width;        // signature box width in points
    int height;       // signature box height in points
    int OrigY;         // orignal y (used internally to save the original y value before it is adjusted for height during comment processing)
    int type;         // PDFFIELD_ constant
    int obj;          // object number for the appearance object - used internally
    int ObjSign;      // object number of the signature object
    int ObjField;     // object containing field information that refers to the signature object
    int SigSpaceOff;  // of the of the space reserved for the ByteRange and Conent tags
    int SigSpaceLen;  // length of the space reserved for the ByteRange and Content tags
    WORD CertName[300];  // signature certificate name
    BYTE DateTime[50];   // signing date/time in D:YYYYMMDDhhmmss or D:YYYYMMDDhhmmss-hh'mm' formats where the last -hh'mm' indicates +/ from gmt time
    WORD reserved[300];  // reserved
};

/****************************************************************************
   Instructions to resume the default structure packing.
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack()
#endif


/******************************************************************************
                     Editor Function Prototype
*******************************************************************************/
#ifndef PDC_CPLUSPLUS
   #if defined(__cplusplus)
      #define PDC_CPLUSPLUS extern "C"
   #else
      #define PDC_CPLUSPLUS
   #endif
#endif

PDC_CPLUSPLUS DWORD_PTR   WINAPI _export PdcStartDoc(LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,DWORD);
PDC_CPLUSPLUS DWORD_PTR   WINAPI _export PdcStartDoc2(LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,DWORD,DWORD,LPBYTE,LPBYTE);
PDC_CPLUSPLUS int     WINAPI _export PdcGetLastMessage(LPBYTE,LPBYTE);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcResetLastMessage(void);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcEndDoc(DWORD_PTR);
PDC_CPLUSPLUS DWORD   WINAPI _export PdcSetFlags(DWORD_PTR,BOOL,DWORD);
PDC_CPLUSPLUS HDC     WINAPI _export PdcStartPage(DWORD_PTR,int,int);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcEndPage(DWORD_PTR);
PDC_CPLUSPLUS HGLOBAL WINAPI _export PdcEndDoc2(DWORD_PTR,LPINT);


// Undocumented functions - do not use them without consultation with Sub Systems, Inc.
PDC_CPLUSPLUS HANDLE  WINAPI _export PdcStrToHandle(BYTE PDC_HUGE *,int);
PDC_CPLUSPLUS HANDLE  WINAPI _export PdcStrToHandleInChunks(BYTE PDC_HUGE *,int,HANDLE,int,int);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcHandleToStr(BYTE PDC_HUGE *,int,HANDLE);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcHandleToStrInChunks(BYTE PDC_HUGE *,int,HANDLE,int,int);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcSaveFile(DWORD_PTR,LPBYTE);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcSaveFileU(DWORD_PTR,LPWORD);
PDC_CPLUSPLUS HGLOBAL WINAPI _export PdcGetData(DWORD_PTR,LPINT);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcSetHlinkBase(DWORD_PTR,LPBYTE);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcNewTEDoc(DWORD_PTR);
PDC_CPLUSPLUS DWORD_PTR   WINAPI _export PdcStartDoc3(LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,DWORD,DWORD,LPBYTE,LPBYTE,LPBYTE);
PDC_CPLUSPLUS DWORD_PTR   WINAPI _export PdcStartDocU(LPBYTE,LPWORD,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,LPBYTE,DWORD,DWORD,LPBYTE,LPBYTE,LPBYTE);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcAbortPage(DWORD_PTR);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcAbortDoc(DWORD_PTR);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcSetPictQuality(DWORD_PTR,int);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcEmbedFile(DWORD_PTR, LPBYTE, LPBYTE, int,LPBYTE);
PDC_CPLUSPLUS BOOL    WINAPI _export PdcEmbedFile2(DWORD_PTR, LPBYTE, LPBYTE, int,LPBYTE,LPBYTE);
PDC_CPLUSPLUS DWORD_PTR WINAPI _export PdcStartDocU2(LPBYTE LicenseKey, LPWORD OutputFile,
    LPWORD author, LPWORD producer, LPWORD title, LPWORD subject, LPWORD keywords,
    LPBYTE date, LPBYTE ModDate, DWORD flags, DWORD PermVals, LPBYTE OwnerPass, LPBYTE UserPass, LPBYTE TempMetaFileName);


#endif
